class TestUtil(object):
    def setup_method(self, method):
        pass

    def teardown_method(self, method):
        pass

    def test_pad_zero(self):
        # assert Util.get("2020-03") == 0
        pass
